==> dicomselect-0.0.0.tar.gz: dicomselect-0.0.0/dicomselect/dicom.py <==
import re
from typing import Callable

from dicomselect.tags_generated import tags_generated, version
from dicomselect.constants import DEFAULT_DICOM_TAGS


def convert_AS(value: str):
    t = value[3]
    value = int(value[:3])
    if t == 'Y':
        value *= 365
    elif t == 'M':
        value *= 30
    elif t == 'W':
        value *= 7
    return value


def convert_DT(value: str):
    value = value.replace(' ', '')
    r = re.search(r'^(\d{14}).?(\d+)?', value)
    return r.group()


# https://dicom.nema.org/medical/dicom/current/output/chtml/part05/sect_6.2.html
VR = {
    "AS": ("INTEGER", convert_AS),
    "DA": "INTEGER",
    "DT": ("REAL", convert_DT),
    "DS": "REAL",
    "FL": "REAL",
    "FD": "REAL",
    "IS": "INTEGER",
    "SL": "INTEGER",
    "SS": "INTEGER",
    "TM": "REAL",
    "UL": "INTEGER",
    "US": "INTEGER"
}


class DICOMTag:
    def __init__(self, tag: str):
        r = re.search(r'(.{4})[,| ]+(.{4})', tag.upper())
        if not r:
            raise ValueError(f'Invalid tag, could not parse {tag}')
        self._tag = r.groups()

        from_generated_tags = tags_generated.get(self.key, None)
        if from_generated_tags is None:
            raise ValueError(f'Invalid tag, does not exist in {version}')

        self._name = from_generated_tags[0]
        vr = VR.get(from_generated_tags[1], "TEXT")
        if isinstance(vr, str):
            vr = (vr, lambda v: v)

        self._datatype = vr[0]
        self._convert_func: Callable[[str], str] = vr[1]

    def __eq__(self, other):
        if isinstance(other, DICOMTag):
            return self.key == other.key
        return False

    @property
    def name(self) -> str:
        return re.sub(r'\W+', '', self._name.replace(' ', '_')).lower()

    @property
    def key(self) -> str:
        return f'{self._tag[0]}|{self._tag[1]}'

    @property
    def column_type(self) -> str:
        return self._datatype

    def convert(self, value: str):
        return self._convert_func(value)

    def __repr__(self):
        return f'{self.key} {self.name} {self.column_type}'


DEFAULT_DICOM_TAGS = [DICOMTag(tag) for tag in DEFAULT_DICOM_TAGS]

==> dicomselect-0.1.0.tar.gz: dicomselect-0.1.0/dicomselect/dicom.py <==
import re
from typing import Callable

from dicomselect.tags_generated import tags_generated, version
from dicomselect.constants import DEFAULT_DICOM_TAGS


def convert_AS(value: str):
    t = value[3]
    value = int(value[:3])
    if t == 'D':
        value /= 365
    elif t == 'M':
        value /= 12
    elif t == 'W':
        value /= 52
    return value


def convert_DT(value: str):
    value = value.replace(' ', '')
    r = re.search(r'^(\d{14}).?(\d+)?', value)
    return r.group()


# https://dicom.nema.org/medical/dicom/current/output/chtml/part05/sect_6.2.html
VR = {
    "AS": ("REAL", convert_AS),
    "DA": "INTEGER",
    "DT": ("REAL", convert_DT),
    "DS": "REAL",
    "FL": "REAL",
    "FD": "REAL",
    "IS": "INTEGER",
    "SL": "INTEGER",
    "SS": "INTEGER",
    "TM": "REAL",
    "UL": "INTEGER",
    "US": "INTEGER"
}


class DICOMTag:
    def __init__(self, tag: str):
        r = re.search(r'(.{4})[,| ]+(.{4})', tag.upper())
        if not r:
            raise ValueError(f'Invalid tag, could not parse {tag}')
        self._tag = r.groups()

        from_generated_tags = tags_generated.get(self.key, None)
        if from_generated_tags is None:
            raise ValueError(f'Invalid tag, does not exist in {version}')

        self._name = from_generated_tags[0]
        vr = VR.get(from_generated_tags[1], "TEXT")
        if isinstance(vr, str):
            vr = (vr, lambda v: v)

        self._datatype = vr[0]
        self._convert_func: Callable[[str], str] = vr[1]

    def __eq__(self, other):
        if isinstance(other, DICOMTag):
            return self.key == other.key
        return False

    @property
    def name(self) -> str:
        return re.sub(r'\W+', '', self._name.replace(' ', '_')).lower()

    @property
    def key(self) -> str:
        return f'{self._tag[0]}|{self._tag[1]}'

    @property
    def column_type(self) -> str:
        return self._datatype

    def convert(self, value: str):
        return self._convert_func(value)

    def __repr__(self):
        return f'{self.key} {self.name} {self.column_type}'


DEFAULT_DICOM_TAGS = [DICOMTag(tag) for tag in DEFAULT_DICOM_TAGS]
